Calculate the reach (node) Strahler for all nodes in a river network. The function will not work if any of the nodes in the network have more than two adjacent upstream reaches (e.g. some networks generated by the OCNet package).
Usage
sbn_strahler(g)
Arguments
g
a river network as an igraph object. Must be a downstream directed graph.